@@ -9,7 +9,18 @@ library(spsurvey)
 
 
 ###################################################
-### code chunk number 2: att
+### code chunk number 2: createshape
+###################################################
+# Load the sp object in the data directory
+data(NE_lakes)
+
+# Create a shapefile
+sp2shape(sp.obj=NE_lakes, shpfilename="NE_lakes")
+
+
+
+###################################################
+### code chunk number 3: att
 ###################################################
 # Read the attribute table from the shapefile
 att <- read.dbf("NE_lakes")
@@ -17,7 +28,7 @@ att <- read.dbf("NE_lakes")
 
 
 ###################################################
-### code chunk number 3: att
+### code chunk number 4: att
 ###################################################
 # Display the initial six lines in the attribute data frame
 head(att)
@@ -25,7 +36,7 @@ head(att)
 
 
 ###################################################
-### code chunk number 4: att
+### code chunk number 5: att
 ###################################################
 # Display number of lakes cross-classified by strata and multidensity
 # category
@@ -34,7 +45,7 @@ addmargins(table("State"=att$State, "Lake Area Category"=att$Area_Cat))
 
 
 ###################################################
-### code chunk number 5: Equalsites
+### code chunk number 6: Equalsites
 ###################################################
 # Call the set.seed function so that the survey designs can be replicate
 set.seed(4447864)
@@ -42,7 +53,7 @@ set.seed(4447864)
 
 
 ###################################################
-### code chunk number 6: Equalsites
+### code chunk number 7: Equalsites
 ###################################################
 # Create the design list
 Equaldsgn <- list(None=list(panel=c(PanelOne=300), seltype="Equal"))
@@ -50,7 +61,7 @@ Equaldsgn <- list(None=list(panel=c(PanelOne=300), seltype="Equal"))
 
 
 ###################################################
-### code chunk number 7: Equalsites
+### code chunk number 8: Equalsites
 ###################################################
 # Select the sample
 Equalsites <- grts(design=Equaldsgn,
@@ -64,7 +75,7 @@ Equalsites <- grts(design=Equaldsgn,
 
 
 ###################################################
-### code chunk number 8: Equalsites
+### code chunk number 9: Equalsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Equalsites@data)
@@ -72,7 +83,7 @@ head(Equalsites@data)
 
 
 ###################################################
-### code chunk number 9: Equalsites
+### code chunk number 10: Equalsites
 ###################################################
 # Print the survey design summary
 summary(Equalsites)
@@ -80,7 +91,7 @@ summary(Equalsites)
 
 
 ###################################################
-### code chunk number 10: Stratsites
+### code chunk number 11: Stratsites
 ###################################################
 # Create the design list
 Stratdsgn <- list(CT=list(panel=c(PanelOne=125), seltype="Equal"),
@@ -90,7 +101,7 @@ Stratdsgn <- list(CT=list(panel=c(PanelOne=125), seltype="Equal"),
 
 
 ###################################################
-### code chunk number 11: Stratsites
+### code chunk number 12: Stratsites
 ###################################################
 # Select the sample
 Stratsites <- grts(design=Stratdsgn,
@@ -106,7 +117,7 @@ Stratsites <- grts(design=Stratdsgn,
 
 
 ###################################################
-### code chunk number 12: Stratsites
+### code chunk number 13: Stratsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Stratsites@data)
@@ -114,7 +125,7 @@ head(Stratsites@data)
 
 
 ###################################################
-### code chunk number 13: Stratsites
+### code chunk number 14: Stratsites
 ###################################################
 # Print the survey design summary
 summary(Stratsites)
@@ -122,7 +133,7 @@ summary(Stratsites)
 
 
 ###################################################
-### code chunk number 14: Unequalsites
+### code chunk number 15: Unequalsites
 ###################################################
 # Read the shapefile
 shp <- read.shape("NE_lakes")
@@ -130,7 +141,7 @@ shp <- read.shape("NE_lakes")
 
 
 ###################################################
-### code chunk number 15: Unequalsites
+### code chunk number 16: Unequalsites
 ###################################################
 # Create the design list
 Unequaldsgn <- list(None=list(panel=c(PanelOne=300),
@@ -143,7 +154,7 @@ Unequaldsgn <- list(None=list(panel=c(PanelOne=300),
 
 
 ###################################################
-### code chunk number 16: Unequalsites
+### code chunk number 17: Unequalsites
 ###################################################
 # Select the sample
 Unequalsites <- grts(design=Unequaldsgn,
@@ -158,7 +169,7 @@ Unequalsites <- grts(design=Unequaldsgn,
 
 
 ###################################################
-### code chunk number 17: Unequalsites
+### code chunk number 18: Unequalsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Unequalsites@data)
@@ -166,7 +177,7 @@ head(Unequalsites@data)
 
 
 ###################################################
-### code chunk number 18: Unequalsites
+### code chunk number 19: Unequalsites
 ###################################################
 # Print the survey design summary
 summary(Unequalsites)
@@ -174,7 +185,7 @@ summary(Unequalsites)
 
 
 ###################################################
-### code chunk number 19: Panelsites
+### code chunk number 20: Panelsites
 ###################################################
 # Create the design list
 Paneldsgn <- list(None=list(panel=c(Annual=50, Year1=50, Year2=50, Year3=50,
@@ -188,7 +199,7 @@ Paneldsgn <- list(None=list(panel=c(Annual=50, Year1=50, Year2=50, Year3=50,
 
 
 ###################################################
-### code chunk number 20: Panelsites
+### code chunk number 21: Panelsites
 ###################################################
 # Select the sample
 Panelsites <- grts(design=Paneldsgn,
@@ -203,7 +214,7 @@ Panelsites <- grts(design=Paneldsgn,
 
 
 ###################################################
-### code chunk number 21: Panelsites (eval = FALSE)
+### code chunk number 22: Panelsites (eval = FALSE)
 ###################################################
 ## # Print the warning message
 ## warnings()
@@ -211,7 +222,7 @@ Panelsites <- grts(design=Paneldsgn,
 
 
 ###################################################
-### code chunk number 22: Panelsites
+### code chunk number 23: Panelsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Panelsites@data)
@@ -219,7 +230,7 @@ head(Panelsites@data)
 
 
 ###################################################
-### code chunk number 23: Panelsites
+### code chunk number 24: Panelsites
 ###################################################
 # Print the survey design summary
 summary(Panelsites)
