@@ -9,7 +9,18 @@ library(spsurvey)
 
 
 ###################################################
-### code chunk number 2: att
+### code chunk number 2: createshape
+###################################################
+# Load the sp object in the data directory
+data(Luck_Ash_streams)
+
+# Create a shapefile
+sp2shape(sp.obj=Luck_Ash_streams, shpfilename="Luck_Ash_streams")
+
+
+
+###################################################
+### code chunk number 3: att
 ###################################################
 # Read the attribute table from the shapefile
 att <- read.dbf("Luck_Ash_streams")
@@ -17,7 +28,7 @@ att <- read.dbf("Luck_Ash_streams")
 
 
 ###################################################
-### code chunk number 3: att
+### code chunk number 4: att
 ###################################################
 # Display the initial six lines in the attribute data frame
 head(att)
@@ -25,7 +36,7 @@ head(att)
 
 
 ###################################################
-### code chunk number 4: att
+### code chunk number 5: att
 ###################################################
 # Display number of stream segments cross-classified by the  strata and
 # multidensity category variables
@@ -35,7 +46,7 @@ addmargins(table("Stream Type"=att$Per_Int, "Strahler Order"=att$Strah_Cat))
 
 
 ###################################################
-### code chunk number 5: att
+### code chunk number 6: att
 ###################################################
 # Summarize frame stream length by stratum and multidensity category
 temp <- tapply(att$Length_km, list(att$Per_Int, att$Strah_Cat), sum)
@@ -46,7 +57,7 @@ temp
 
 
 ###################################################
-### code chunk number 6: Equalsites
+### code chunk number 7: Equalsites
 ###################################################
 # Call the set.seed function so that the survey designs can be replicate
 set.seed(19742003)
@@ -54,7 +65,7 @@ set.seed(19742003)
 
 
 ###################################################
-### code chunk number 7: Equalsites
+### code chunk number 8: Equalsites
 ###################################################
 # Create the design list
 Equaldsgn <- list(None=list(panel=c(PanelOne=50), seltype="Equal"))
@@ -62,7 +73,7 @@ Equaldsgn <- list(None=list(panel=c(PanelOne=50), seltype="Equal"))
 
 
 ###################################################
-### code chunk number 8: Equalsites
+### code chunk number 9: Equalsites
 ###################################################
 # Select the sample
 Equalsites <- grts(design=Equaldsgn,
@@ -76,7 +87,7 @@ Equalsites <- grts(design=Equaldsgn,
 
 
 ###################################################
-### code chunk number 9: Equalsites
+### code chunk number 10: Equalsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Equalsites@data)
@@ -84,7 +95,7 @@ head(Equalsites@data)
 
 
 ###################################################
-### code chunk number 10: Equalsites
+### code chunk number 11: Equalsites
 ###################################################
 # Print the survey design summary
 summary(Equalsites)
@@ -92,7 +103,7 @@ summary(Equalsites)
 
 
 ###################################################
-### code chunk number 11: Stratsites
+### code chunk number 12: Stratsites
 ###################################################
 # Create the design list
 Stratdsgn <- list(Perennial=list(panel=c(PanelOne=50),
@@ -105,7 +116,7 @@ Stratdsgn <- list(Perennial=list(panel=c(PanelOne=50),
 
 
 ###################################################
-### code chunk number 12: Stratsites
+### code chunk number 13: Stratsites
 ###################################################
 # Select the sample
 Stratsites <- grts(design=Stratdsgn,
@@ -120,7 +131,7 @@ Stratsites <- grts(design=Stratdsgn,
 
 
 ###################################################
-### code chunk number 13: Stratsites
+### code chunk number 14: Stratsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Stratsites@data)
@@ -128,7 +139,7 @@ head(Stratsites@data)
 
 
 ###################################################
-### code chunk number 14: Stratsites
+### code chunk number 15: Stratsites
 ###################################################
 # Print the survey design summary
 summary(Stratsites)
@@ -136,7 +147,7 @@ summary(Stratsites)
 
 
 ###################################################
-### code chunk number 15: Unequalsites
+### code chunk number 16: Unequalsites
 ###################################################
 # Read the shapefile
 shp <- read.shape("Luck_Ash_streams")
@@ -144,7 +155,7 @@ shp <- read.shape("Luck_Ash_streams")
 
 
 ###################################################
-### code chunk number 16: Unequalsites
+### code chunk number 17: Unequalsites
 ###################################################
 # Create the design list
 Unequaldsgn <- list(Perennial=list(panel=c(PanelOne=75),
@@ -159,7 +170,7 @@ Unequaldsgn <- list(Perennial=list(panel=c(PanelOne=75),
 
 
 ###################################################
-### code chunk number 17: Unequalsites
+### code chunk number 18: Unequalsites
 ###################################################
 # Select the sample
 Unequalsites <- grts(design=Unequaldsgn,
@@ -175,7 +186,7 @@ Unequalsites <- grts(design=Unequaldsgn,
 
 
 ###################################################
-### code chunk number 18: Unequalsites
+### code chunk number 19: Unequalsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Unequalsites@data)
@@ -183,7 +194,7 @@ head(Unequalsites@data)
 
 
 ###################################################
-### code chunk number 19: Unequalsites
+### code chunk number 20: Unequalsites
 ###################################################
 # Print the survey design summary
 summary(Unequalsites)
@@ -191,7 +202,7 @@ summary(Unequalsites)
 
 
 ###################################################
-### code chunk number 20: Panelsites
+### code chunk number 21: Panelsites
 ###################################################
 # Create the design list
 Paneldsgn <- list(Perennial=list(panel=c(Annual=16, Year1=17, Year2=17),
@@ -205,7 +216,7 @@ Paneldsgn <- list(Perennial=list(panel=c(Annual=16, Year1=17, Year2=17),
 
 
 ###################################################
-### code chunk number 21: Panelsites
+### code chunk number 22: Panelsites
 ###################################################
 # Select the sample
 Panelsites <- grts(design=Paneldsgn,
@@ -221,7 +232,7 @@ Panelsites <- grts(design=Paneldsgn,
 
 
 ###################################################
-### code chunk number 22: Panelsites
+### code chunk number 23: Panelsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Panelsites@data)
@@ -229,7 +240,7 @@ head(Panelsites@data)
 
 
 ###################################################
-### code chunk number 23: Panelsites
+### code chunk number 24: Panelsites
 ###################################################
 # Print the survey design summary
 summary(Panelsites)
