@@ -4,6 +4,7 @@
 **  Date:        May 19, 2010
 **  Revised:     February 23, 2015
 **  Revised:     May 5, 2015
+**  Revised:     June 15, 2015
 **  Description:
 **    For each grid cell, this function determines the set of shapefile records
 **    contained in the cell and returns the shapefile record IDs and the clipped
@@ -41,8 +42,8 @@
 
 /* These functions are found in shapeParser.c */
 extern int parseHeader(FILE * fptr, Shape * shape);
-extern int readLittleEndian(unsigned char * buffer, int length);
-extern int readBigEndian(unsigned char * buffer, int length);
+extern unsigned int readLittleEndian(unsigned char * buffer, int length);
+extern unsigned int readBigEndian(unsigned char * buffer, int length);
 
 /* These functions are found in grts.c */
 extern int combineShpFiles(FILE * newShp, unsigned int * ids, int numIDs);
@@ -62,7 +63,9 @@ SEXP insideAreaGridCell(SEXP fileNamePrefix, SEXP dsgnmdIDVec, SEXP cellIDsVec,
   int i, j, k;                /* loop counters */
   FILE * fptr = NULL;         /* pointer to the shapefile */
   FILE * newShp = NULL;       /* pointer to the temporary .shp file */
-  char * restrict shpFileName = NULL;  /* stores full shape file name */
+  unsigned int fileNameLen = 0;  /* length of the shapefile name */
+  const char * shpExt = ".shp";  /* shapefile extension */
+  char * restrict shpFileName = NULL;  /* stores the full .shp file name */
   int singleFile = FALSE;
   Shape shape;           /* used to store shapefile info and data */
   Point * part = NULL;   /* stores points in a part */
@@ -78,7 +81,7 @@ SEXP insideAreaGridCell(SEXP fileNamePrefix, SEXP dsgnmdIDVec, SEXP cellIDsVec,
   Record record;         /* record used for parsing records */
   Cell cell;             /* temporary storage for a cell */
   unsigned int * dsgnmdID = NULL;  /* array of shapefile record IDs to use */
-  int dsgSize = length(dsgnmdIDVec);  /* number of values in the dsgnmdID array */
+  unsigned int dsgSize = length(dsgnmdIDVec);  /* number of values in the dsgnmdID array */
   unsigned int numCells = length(xcVec); /* number of cells */
   unsigned int * recordIDs[numCells];  /* array that stores record IDs for each cell */
   double * recordAreas[numCells];      /* array that stores record areas for each cell */
@@ -103,15 +106,15 @@ SEXP insideAreaGridCell(SEXP fileNamePrefix, SEXP dsgnmdIDVec, SEXP cellIDsVec,
   if(fileNamePrefix != R_NilValue) {
 
     /* create the full .shp file name */
-    if((shpFileName = (char * restrict)malloc(strlen(CHAR(STRING_ELT(fileNamePrefix,0)))
-                                              + strlen(".shp") + 1)) == NULL){
-      Rprintf("Error: Allocating memory in C function insideAreaGridCell.\n");
-      PROTECT(results = allocVector(VECSXP, 1));
-      UNPROTECT(1);
+    fileNameLen = strlen(CHAR(STRING_ELT(fileNamePrefix, 0))) + strlen(shpExt);
+    if ((shpFileName = (char * restrict)malloc(fileNameLen + 1)) == NULL ) {
+      Rprintf( "Error: Allocating memory in C function insideAreaGridCell\n" );
+      PROTECT( results = allocVector( VECSXP, 1 ) );
+      UNPROTECT( 1 );
       return results;
     }
-    strcpy(shpFileName, CHAR(STRING_ELT(fileNamePrefix,0)));
-    strcat(shpFileName, ".shp");
+    strcpy( shpFileName, CHAR(STRING_ELT(fileNamePrefix, 0)));
+    strcat( shpFileName, shpExt );
     singleFile = TRUE;
   }
 
@@ -836,9 +839,6 @@ SEXP insideAreaGridCell(SEXP fileNamePrefix, SEXP dsgnmdIDVec, SEXP cellIDsVec,
     free(numIDs);
   }
   fclose(fptr);
-  if(singleFile == TRUE) {
-    free(shpFileName);
-  }
   remove(TEMP_SHP_FILE);
   UNPROTECT(5);
 
